=====================
 Invenio-Base v1.0.0
=====================

Invenio-Base v1.0.0 was released on January 13, 2016.

About
-----

Base package for building the Invenio application.

*This is an experimental developer preview release.*

Installation
------------

   $ pip install invenio-base==1.0.0

Documentation
-------------

   http://pythonhosted.org/invenio-base/

Happy hacking and thanks for flying Invenio-Base.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-base
|   URL: http://invenio-software.org
